@@ -371,8 +371,7 @@ class ExportMixin(BaseExportMixin, ImportExportMixinBase):
             'list_editable': self.list_editable,
             'model_admin': self,
         }
-        if django.VERSION >= (2, 1):
-            changelist_kwargs['sortable_by'] = self.sortable_by
+        changelist_kwargs['sortable_by'] = self.sortable_by
         if django.VERSION >= (4, 0):
             changelist_kwargs['search_help_text'] = self.search_help_text
         cl = ChangeList(**changelist_kwargs)
@@ -400,12 +399,19 @@ class ExportMixin(BaseExportMixin, ImportExportMixinBase):
     def get_context_data(self, **kwargs):
         return {}
 
+    def get_export_form(self):
+        """
+        Get the form type used to read the export format.
+        """
+        return ExportForm
+
     def export_action(self, request, *args, **kwargs):
         if not self.has_export_permission(request):
             raise PermissionDenied
 
         formats = self.get_export_formats()
-        form = ExportForm(formats, request.POST or None)
+        form_type = self.get_export_form()
+        form = form_type(formats, request.POST or None)
         if form.is_valid():
             file_format = formats[
                 int(form.cleaned_data['file_format'])
